"""
A really boring CMF tool.

This can be used to help understand the minimal stuff
needed to create and install a CMF tool that provides actions.

"""

# Zope imports
from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
from OFS.SimpleItem import SimpleItem

# CMF imports
from Products.CMFCore.utils import UniqueObject
from Products.CMFCore.ActionProviderBase import ActionProviderBase
from Products.CMFCore.ActionInformation import ActionInformation
from Products.CMFCore.Expression import Expression


# It's common to use the same permission(s) many times in
# one module, so let's make things a bit easier to maintain
# by defining the one we want to use as a global.
# This can be any string you want.
# You should re-use existing core Zope / CMF / Plone permissions
# whenever relevant.
# At the risk of being interesting, we will define our own
# permission.
PERMISSION = "CMFBoringTool: Use Boring Tool"

class BoringTool(UniqueObject, SimpleItem, ActionProviderBase):
    """A tool that does nothing interesting.

    To prevent people from adding more than one to a portal,
    we subclass UniqueObject.

    To provide actions, we subclass ActionProviderBase.

    To be a simple zope persistent object, we subclass 
    SimpleItem. If we needed to keep some sub-objects inside this 
    tool, we could instead subclass Folder or another ObjectManager 
    class.
    """
    
    # first we need to set some class attributes
    id = 'portal_boring_tool'
    # meta_type shows up in the products Add list    
    meta_type = 'CMF Boring Tool'
    # This class implements the same interfaces as ActionProviderBase.
    # This lets us register and provide actions.
    __implements__ = (ActionProviderBase.__implements__,)
    # Tabs for the Zope Management Interface.
    manage_options = ActionProviderBase.manage_options + \
                     SimpleItem.manage_options
    # Needed for declarative security.
    security = ClassSecurityInfo()

    # Let's provide some actions.
    # This is a list of ActionInformation instances.
    _actions = [
        ActionInformation(
            # id of the action.
            id='boring_main',
            # Name of action that will be shown to the user.
            title='Nothing Interesting',
            # URL of the action. Can be any TALES expression.
            # Typically, it is the name of a form that is provided
            # by your skins.
            action=Expression(text='string: boring_main_form'),
            # condition determines whether or not the action can
            # be seen. Again, this is a TALES expression.
            condition=Expression(text='python: 1'),
            # Permissions you must have to perform this action.
            permissions=(PERMISSION,),
            # category in which to display this action.
            category='global',
            # Whether or not the action is visible
            # (assuming the condition & permissions are OK).
            visible=1
            ),
        # More than one action might be too interesting, so we'll stop there.
       
        ]

    # now let's provide one useless method,
    # and declare security restrictions on it.
    security.declareProtected(PERMISSION, 'doBoring')
    def doBoring(self, user_input=""):
        """Show the user's input."""
        result = "You called doBoring with this input: %s" % user_input
        return result
        

InitializeClass(BoringTool)

